## dbt-redshift 1.9.5 - May 13, 2025

### Features

- Add 'serverless_work_group' and 'serverless_acct_id' params to profile and connection calls ([#919](https://github.com/dbt-labs/dbt-adapters/issues/919))

### Fixes

- fix retry_all exception handling ([#1069](https://github.com/dbt-labs/dbt-adapters/issues/1069))

### Under the Hood

- allow users to declare redshift_connector debug logging via env var ([#1062](https://github.com/dbt-labs/dbt-adapters/issues/1062))

### Contributors
- [@csquire](https://github.com/csquire) ([#919](https://github.com/dbt-labs/dbt-adapters/issues/919))
